@@ -10,24 +10,27 @@
 */
 #include "knewpassworddialog.h"
 
+#include <QMessageBox>
 #include <QPushButton>
 #include <QString>
 #include <QStyleOption>
-#include <QMessageBox>
 
 #include <ktitlewidget.h>
 
 #include "ui_knewpassworddialog.h"
 
-class Q_DECL_HIDDEN KNewPasswordDialog::KNewPasswordDialogPrivate
+class KNewPasswordDialogPrivate
 {
+    Q_DECLARE_TR_FUNCTIONS(KNewPasswordDialog)
+
 public:
     KNewPasswordDialogPrivate(KNewPasswordDialog *parent)
         : q(parent)
-    {}
+    {
+    }
 
     void init();
-    void _k_passwordStatusChanged();
+    void passwordStatusChanged();
     void showMessageWidget(const QString &message, KMessageWidget::MessageType type);
 
     KNewPasswordDialog *const q;
@@ -38,17 +41,19 @@ public:
     Ui::KNewPasswordDialog ui;
 };
 
-void KNewPasswordDialog::KNewPasswordDialogPrivate::init()
+void KNewPasswordDialogPrivate::init()
 {
     ui.setupUi(q);
     q->setIcon(QIcon::fromTheme(QStringLiteral("dialog-password")));
 
     ui.statusMsgWidget->hide();
 
-    connect(ui.pwdWidget, SIGNAL(passwordStatusChanged()), q, SLOT(_k_passwordStatusChanged()));
+    QObject::connect(ui.pwdWidget, &KNewPasswordWidget::passwordStatusChanged, q, [this]() {
+        passwordStatusChanged();
+    });
 }
 
-void KNewPasswordDialog::KNewPasswordDialogPrivate::_k_passwordStatusChanged()
+void KNewPasswordDialogPrivate::passwordStatusChanged()
 {
     switch (ui.pwdWidget->passwordStatus()) {
     case KNewPasswordWidget::PasswordTooShort:
@@ -73,7 +78,7 @@ void KNewPasswordDialog::KNewPasswordDialogPrivate::_k_passwordStatusChanged()
     }
 }
 
-void KNewPasswordDialog::KNewPasswordDialogPrivate::showMessageWidget(const QString &message, KMessageWidget::MessageType type)
+void KNewPasswordDialogPrivate::showMessageWidget(const QString &message, KMessageWidget::MessageType type)
 {
     ui.statusMsgWidget->setText(message);
     ui.statusMsgWidget->setMessageType(type);
@@ -85,15 +90,13 @@ void KNewPasswordDialog::KNewPasswordDialogPrivate::showMessageWidget(const QStr
  */
 
 KNewPasswordDialog::KNewPasswordDialog(QWidget *parent)
-    : QDialog(parent), d(new KNewPasswordDialogPrivate(this))
+    : QDialog(parent)
+    , d(new KNewPasswordDialogPrivate(this))
 {
     d->init();
 }
 
-KNewPasswordDialog::~KNewPasswordDialog()
-{
-    delete d;
-}
+KNewPasswordDialog::~KNewPasswordDialog() = default;
 
 void KNewPasswordDialog::setPrompt(const QString &prompt)
 {
@@ -130,11 +133,7 @@ void KNewPasswordDialog::setPixmap(const QPixmap &pixmap)
 
 QPixmap KNewPasswordDialog::pixmap() const
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
     return d->ui.labelIcon->pixmap(Qt::ReturnByValue);
-#else
-    return *d->ui.labelIcon->pixmap();
-#endif
 }
 #endif
 
@@ -144,16 +143,16 @@ bool KNewPasswordDialog::checkAndGetPassword(QString *pwd)
 
     if (d->ui.pwdWidget->passwordStatus() == KNewPasswordWidget::WeakPassword) {
         QMessageBox::StandardButton selectedButton = QMessageBox::warning(this,
-                tr("Low Password Strength", "@title:window"),
-                tr("The password you have entered has a low strength. "
-                   "To improve the strength of "
-                   "the password, try:\n"
-                   " - using a longer password;\n"
-                   " - using a mixture of upper- and lower-case letters;\n"
-                   " - using numbers or symbols as well as letters.\n"
-                   "\n"
-                   "Would you like to use this password anyway?"),
-                QMessageBox::Yes | QMessageBox::No);
+                                                                          tr("Low Password Strength", "@title:window"),
+                                                                          tr("The password you have entered has a low strength. "
+                                                                             "To improve the strength of "
+                                                                             "the password, try:\n"
+                                                                             " - using a longer password;\n"
+                                                                             " - using a mixture of upper- and lower-case letters;\n"
+                                                                             " - using numbers or symbols as well as letters.\n"
+                                                                             "\n"
+                                                                             "Would you like to use this password anyway?"),
+                                                                          QMessageBox::Yes | QMessageBox::No);
 
         if (selectedButton == QMessageBox::No) {
             return false;
@@ -174,7 +173,7 @@ void KNewPasswordDialog::accept()
         return;
     }
     d->pass = pwd;
-    emit newPassword(d->pass);
+    Q_EMIT newPassword(d->pass);
     QDialog::accept();
 }
 
@@ -261,4 +260,3 @@ bool KNewPasswordDialog::checkPassword(const QString &)
 }
 
 #include "moc_knewpassworddialog.cpp"
-
